#R script for analyzing Aphonopelma morphological space
#by Chris Hamilton, 2015

#In order to compare your morphological data with that used in our revision, you will need to take our species measurements dataset and add your data.
#After you have measured your specimen/s, you will need to put them into a spreadsheet and transform the measurements into their log normal values - this will help normalize differences in size variation.

#You will need to change filenames and certain other numbers (see notes below)

require(ggplot2)
#Read your CSV datafile into R
data1<-read.csv("put_file_here.csv",header=T)
#Run PCA analysis - you need to change the number of columns of data you want to perform the pca
pca1<-prcomp(data1[,1st column of data:last column of data])
#This will print your PC scores to an output file
capture.output(summary(pca1), file="PC_scores.txt")
#
#Change the data into a dataframe
scores1=as.data.frame(pca1$x)
#Write the dataframe to a file
write.csv(scores1, file="name_scores_file_here.csv")
#
#Take column 1 from 'data' file and put that column into the 'scores' file (so that the species names are there instead of numbers)
scores1$species <- data1$species
#Resave that file
write.csv(scores1, file="resave_the_scores_file.csv")
#
#Read that renamed file of PCA scores into R
pca1 <- read.csv("read_that_scores_file_again.csv")
#
#Plot the PC1~PC2 data and save as PDF
a <- ggplot(data = pca1, aes(x = PC1, y = PC2, col = species, shape = species))
a <- a + geom_point(size = 4, position = "jitter")
#Gives each group a discrete color
a <- a + scale_colour_discrete()
#The numbers in (#,...) correspond to how many different entities, or species, you are plotting and gives them a discrete shape/symbol
a <- a + scale_shape_manual(values=c(1,2,3,...))
a
ggsave(file="name_file_PC1~PC2.pdf", width=10, height=10)
#
#Plot the PC2~PC3 data and save as PDF
b <- ggplot(data = pca1, aes(x = PC2, y = PC3, col = species, shape = species))
b <- b + geom_point(size = 4, position = "jitter")
b <- b + scale_colour_discrete()
b <- b + scale_shape_manual(values=c(1,2,3,...))
b
ggsave(file="name_file_PC2~PC3.pdf", width=10, height=10)
#
#
#
##Plot the first three PCs in 3D (Aphonopelma morphospace in 3D) to screen
##This only prints to the screen. You can rotate this with your mouse by clicking, holding, and moving
##You can also zoom in and out using the wheel on your mouse or using your trackpad
##The legend is printed to the screen, or you can add the commented out command (below)...but I can't get the screen output to save to a file AND I can't get the species names to resize to a smaller size.
library(rgl)
library(pca3d)
data <- read.csv("put_file_here.csv",header=T)
pca2 <- prcomp(data[,-1], scale.=TRUE)
#pca3d (pca2, group = data[,1], components = 1:3, title = NULL, new = FALSE, axes.color = "grey", bg = "white", show.group.labels=TRUE)
#
##Plot the first three PCs in 3D (Aphonopelma morphospace in 3D) & save as GIF
pca3d(pca2,group=data[,1])
##rotate 3D space
rot<-spin3d(axis=c(0,1,0))
##set PATH where 'convert' package is...if it is not in your PATH already
Sys.setenv(PATH=paste("/sw/bin", Sys.getenv("PATH"), sep=":"))
##animates the rotating 3D space
movie3d(rot,duration= 12)
##[The output gets saved in a temporary directory and the PATH will be printed to the R console]
##[I cannot figure out another way to save it somewhere else; you'll need to copy or move the file - I did it by using 'cp' in shell]
##[You can change the angle of the axes, zoom in or out, and make the window bigger for a larger output, then rerun the script again if you'd like to fine-tune the way the GIF looks]
###Writing movie120.png [this is just output to the screen]
###Will create:  /PATH/movie.gif [it will place the whole path here]
###Executing:  convert -delay 1x10 movie*.png movie.gif 
###Deleting frames

##you can then move that file via shell commands (below)
##cp /PATH/movie.gif ~/Desktop/3D.gif
#system("cp /PATH/movie.gif ~/Desktop/3D.gif")

#If you don't like the grey background, you can get rid of it using the change in code below
#a <- ggplot(data = pca1, aes(x = PC1, y = PC2, col = species, shape = species))
#This command (below) is what gives it the white background
#a <- a + theme_minimal()
#a <- a + geom_point(size = 4, position = "jitter")
#Gives each group a discrete color
#a <- a + scale_colour_discrete()
#The numbers in (#,...) correspond to how many different entities, or species, you are plotting and gives them a discrete shape/symbol
#a <- a + scale_shape_manual(values=c(1,2,3,...))
#a
#ggsave(file="name_file_PC1~PC2.pdf", width=10, height=10)